import * as _nuxt_schema from '@nuxt/schema';
import { Options } from 'nodemailer/lib/smtp-transport';

interface ModuleOptions {
    /**
     * Tipo de transporte a usar: 'smtp' o 'ses'.
     */
    transport: 'smtp' | 'ses';
    /**
     * Dirección de remitente por defecto para todos los correos.
     * Puede ser sobreescrita al llamar a send().
     * Ejemplo: 'Tu Nombre <noreply@example.com>'
     */
    defaultFrom?: string;
    /**
     * Configuración para el transporte SMTP.
     * Requerido si transport es 'smtp'.
     */
    smtp?: Options;
    /**
     * Configuración para el transporte AWS SES.
     * Requerido si transport es 'ses'.
     */
    ses?: {
        /**
         * Región de AWS donde se encuentra el servicio SES.
         */
        region: string;
        /**
         * Credenciales de AWS (accessKeyId y secretAccessKey).
         */
        credentials?: {
            accessKeyId: string;
            secretAccessKey: string;
        };
        /**
         * Tasa máxima de envío de correos por segundo.
         */
        sendingRate?: number;
        /**
         * Número máximo de conexiones simultáneas.
         */
        maxConnections?: number;
    };
    /**
     * Configuración de plantillas Handlebars.
     */
    templates?: {
        /**
         * Directorio donde se encuentran las plantillas .hbs.
         * Ruta relativa al directorio raíz del proyecto Nuxt.
         * @default 'server/emails/templates'
         */
        dir?: string;
    };
}

declare const _default: _nuxt_schema.NuxtModule<ModuleOptions, ModuleOptions, false>;

export { _default as default };
