import { defineNuxtModule, createResolver, addServerImportsDir, addPlugin } from '@nuxt/kit';

const MODULE_NAME = "nuxt-arpix-email-sender";
const CONFIG_KEY = "arpixEmailSender";
const module = defineNuxtModule({
  meta: {
    name: MODULE_NAME,
    configKey: CONFIG_KEY,
    compatibility: {
      nuxt: "^3.0.0 || ^4.0.0"
    }
  },
  // Default configuration options of the Nuxt module
  defaults: {
    transport: void 0,
    templates: {
      dir: "server/emails/templates"
      // Directory where the templates are located
    }
  },
  setup(_options, _nuxt) {
    const resolver = createResolver(import.meta.url);
    if (!_options.transport || _options.transport === "smtp" && !_options.smtp) {
      console.warn(`[${MODULE_NAME}] The transport configuration ('transport' and 'smtp') is required. The module will not work.`);
      return;
    }
    _nuxt.options.runtimeConfig[CONFIG_KEY] = _options;
    const runtimeDir = resolver.resolve("./runtime/server/utils");
    addServerImportsDir(runtimeDir);
    console.log(`[${MODULE_NAME}] Module set up with transport: ${_options.transport}`);
    addPlugin(resolver.resolve("./runtime/plugin"));
  }
});

export { module as default };
